@@ -58,7 +58,7 @@ sub parse {
     elsif ($self->isNewNat($string))     { $self->parseNewNat($string) }
     else                                 { $self->ignoreLine }
   }
-} ## end sub parse
+}
 
 sub isNewNat {
   my ($self, $string) = @_;
@@ -150,8 +150,8 @@ sub parseNewNat {
           $params{ruleName}    = $dstnat;
           my $dyNat = Firewall::Config::Element::DynamicNat::Asa->new(%params);
           $self->addElement($dyNat);
-        } ## end if ( defined $dstnat and...)
-      } ## end elsif ( defined $snatObj ...)
+        }
+      }
     }
     elsif ($snatType eq 'dynamic') {
       my %params;
@@ -181,9 +181,9 @@ sub parseNewNat {
         my $dstAddr = $self->getAddressGroup($dst);
         $dyNat->{dstIpRange} = $dstAddr->range;
       }
-    } ## end elsif ( $snatType eq 'dynamic')
-  } ## end if ( $string =~ ...)
-} ## end sub parseNewNat
+    }
+  }
+}
 
 #nat (corporation) 121 access-list 121
 sub isDynamicNat {
@@ -232,7 +232,7 @@ sub parseDynamicNat {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseDynamicNat
+}
 
 # global (outside) 131 172.16.18.44
 sub isNatPool {
@@ -286,7 +286,7 @@ sub parseNatPool {
   }
   my $natPool = Firewall::Config::Element::NatPool::Asa->new(%param);
   $self->addElement($natPool);
-} ## end sub parseNatPool
+}
 
 sub isStaticNat {
   my ($self, $string) = @_;
@@ -353,7 +353,7 @@ sub parseStaticNat {
   }
   my $staticNat = Firewall::Config::Element::StaticNat::Asa->new(%param);
   $self->addElement($staticNat);
-} ## end sub parseStaticNat
+}
 
 #access-group outside_access_in in interface outside
 sub isAclGroup {
@@ -458,15 +458,15 @@ sub parseInterfaceZone {
             $self->addElement($interface);
           }
           $zone->addInterface($interface);
-        } ## end if ( defined $zoneName)
+        }
         return;
-      } ## end elsif ( $string =~ /^!/ )
-    } ## end while ( my $string = $self...)
+      }
+    }
   }
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseInterfaceZone
+}
 
 sub isRoute {
   my ($self, $string) = @_;
@@ -506,7 +506,7 @@ sub parseRoute {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseRoute
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -697,18 +697,18 @@ sub parseAddressGroup {
           }
           my $dynamicNat = Firewall::Config::Element::DynamicNat::Asa->new(%params);
           $self->addElement($dynamicNat);
-        } ## end elsif ( $+{natType} eq 'dynamic')
+        }
       }
       else {
         $self->backtrackLine;
         return;
       }
-    } ## end while ( my $string = $self...)
+    }
   }
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseAddressGroup
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $addrGroupMemberName) = @_;
@@ -730,7 +730,7 @@ sub getAddressOrAddressGroupFromAddrGroupMemberName {
     $obj->{refnum} += 1 if defined $obj;
   }
   return $obj;
-} ## end sub getAddressOrAddressGroupFromAddrGroupMemberName
+}
 
 sub isServiceGroup {
   my ($self, $string) = @_;
@@ -815,18 +815,18 @@ sub parseServiceGroup {
             protocol => $protocol
           );
           $serviceGroup->addSrvGroupMember($srvName, $service);
-        } ## end else [ if ( defined $+{srvGroupMemberName...})]
+        }
       }
       else {
         $self->backtrackLine;
         return;
       }
-    } ## end while ( my $string = $self...)
+    }
   }
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseServiceGroup
+}
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
   my ($self, $srvGroupMemberName, $srvGroupName, @protocols) = @_;
@@ -867,9 +867,9 @@ sub getServiceOrServiceGroupFromSrvGroupMemberName {
     else {
       $self->warn("srvGroup $srvGroupName 的 srvGroupMember ($srvGroupMemberName) 里含有 既不是数字也不是 pre-defined service 的字符串\n");
     }
-  } ## end else [ if ( $srvGroupMemberName...)]
+  }
   return $obj;
-} ## end sub getServiceOrServiceGroupFromSrvGroupMemberName
+}
 
 sub getPortNumber {
   my ($self, $portString) = @_;
@@ -938,7 +938,7 @@ sub parseProtocolGroup {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseProtocolGroup
+}
 
 sub getProtocolOrProtocolGroupFromProGroupMemberName {
   my ($self, $proGroupMemberName, $protocolObjType) = @_;
@@ -1022,7 +1022,7 @@ sub parseSchedule {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseSchedule
+}
 
 sub isRule {
   my ($self, $string) = @_;
@@ -1152,7 +1152,7 @@ sub parseRule {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseRule
+}
 
 sub parseRuleProtocol {
   my ($self, $rule, $protocolInfo, $protocolObjType) = @_;
@@ -1201,7 +1201,7 @@ sub parseRuleDstAddress {
   }
 
   $rule->addDstAddressMembers($dstAddressInfo, $obj);
-} ## end sub parseRuleDstAddress
+}
 
 sub parseRuleService {
   my ($self, $rule, $serviceInfo) = @_;
@@ -1277,14 +1277,14 @@ sub parseRuleService {
           }
           $serviceGroup->addSrvGroupMember('_rule_service_filter_by_protocol_', $obj);
         }
-      } ## end if ( keys %protocols )
-    } ## end else [ if ( $rule->protocolGroup...)]
+      }
+    }
   }
   else {
 
   }
   $rule->addServiceMembers($serviceGroup->srvGroupName, $serviceGroup);
-} ## end sub parseRuleService
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
