@@ -43,7 +43,7 @@ sub parse {
 
     #elsif ( $self->isActive($string)       ) { $self->setActive($string)         }
     else { $self->ignoreLine }
-  } ## end while ( defined( my $string...))
+  }
   $self->completeObj();
   $self->addRouteToInterface;
   $self->addZoneRange;
@@ -57,7 +57,7 @@ sub parse {
 
   $self->{config} = "";
 
-} ## end sub parse
+}
 
 sub completeObj {
   my $self = shift;
@@ -85,7 +85,7 @@ sub completeObj {
     }
   }
 
-} ## end sub completeObj
+}
 
 sub isZonePair {
   my ($self, $string) = @_;
@@ -123,11 +123,11 @@ sub parseZonePair {
         print "can't parser $string";
       }
 
-    } ## end while ( defined( my $string...))
+    }
 
-  } ## end if ( $string =~ /zone-pair\s+security\s+source\s+(?<fromZone>\S+)\s+destination\s+(?<toZone>\S+)/i)
+  }
 
-} ## end sub parseZonePair
+}
 
 sub isAcl {
   my ($self, $string) = @_;
@@ -199,8 +199,8 @@ sub parseAcl {
         my $obj = Firewall::Config::Element::Service::H3c->new(srvName => 'any', protocol => 'any');
         $rule->addServiceMembers('any', $obj);
 
-      } ## end if ( $string =~ ...)
-    } ## end while ( defined( my $string...))
+      }
+    }
 
   }
   elsif ($string =~ /acl\s+advanced\s+((?<id>\d+)|name\s+(?<name>\S+))\s*/i) {
@@ -327,9 +327,9 @@ sub parseAcl {
                 my $name    = $protocol . "/" . $dstPort;
                 $obj->addMeta(srvName => $name, protocol => $protocol, dstPort => $dstPort);
               }
-            } ## end for my $portrange ( @{$portObj...})
+            }
             $rule->addServiceMembers($port, $obj);
-          } ## end elsif ( $opt eq 'object-group')
+          }
 
         }
         else {
@@ -338,12 +338,12 @@ sub parseAcl {
         }
 
         $self->addElement($rule);
-      } ## end if ( $string =~ /rule\s+(?<aclRuleNum>\d+)\s+(?<action>deny|permit)\s+(?<protocol>\S+) )
-    } ## end while ( defined( my $string...))
+      }
+    }
 
-  } ## end elsif ( $string =~ /acl\s+advanced\s+((?<id>\d+)|name\s+(?<name>\S+))\s*/i)
+  }
 
-} ## end sub parseAcl
+}
 
 sub changeWildMaskToMaskNum {
   my ($self, $wildMask) = @_;
@@ -439,7 +439,7 @@ sub parseStaticNat {
   }
   my $staticnat = Firewall::Config::Element::StaticNat::H3c->new(%params);
   $self->addElement($staticnat);
-} ## end sub parseStaticNat
+}
 
 sub isNatPool {
   my ($self, $string) = @_;
@@ -481,8 +481,8 @@ sub parseNatPool {
     if (defined $params{name}) {
       $self->elements->natPool->{$params{name}} = $natpool;
     }
-  } ## end if ( $string =~ /nat\s+address-group\s+(?<id>\d+)(\s+name\s+(?<name>\S+))?/i)
-} ## end sub parseNatPool
+  }
+}
 
 sub isInterface {
   my ($self, $string) = @_;
@@ -536,9 +536,9 @@ sub parseInterface {
         $self->ignoreLine;
       }
 
-    } ## end while ( defined( $string ...))
-  } ## end if ( $string =~ /^interface\s+(?<name>\S+)/i)
-} ## end sub parseInterface
+    }
+  }
+}
 
 sub isZone {
   my ($self, $string) = @_;
@@ -577,9 +577,9 @@ sub parseZone {
       }
 
     }
-  } ## end if ( $string =~ /security-zone\s+name\s+(?<name>\S+)/i)
+  }
 
-} ## end sub parseZone
+}
 
 sub isPortObj {
   my ($self, $string) = @_;
@@ -673,9 +673,9 @@ sub parseAddress {
         $self->warn("can't parse address" . $string);
       }
 
-    } ## end while ( defined( $string ...))
-  } ## end if ( $string =~ /object-group\s+ip\s+address\s+((?<name>\S+)|"(?<name>.+?)")/i)
-} ## end sub parseAddress
+    }
+  }
+}
 
 sub isService {
   my ($self, $string) = @_;
@@ -761,11 +761,11 @@ sub parseService {
         $self->warn("can't parse service" . $string);
       }
 
-    } ## end while ( defined( $string ...))
+    }
     $service->{config} = $config;
-  } ## end if ( $string =~ /object-group\s+service\s+((?<name>\S+)|"(?<name>.+?)")/i)
+  }
 
-} ## end sub parseService
+}
 
 sub getPreDefinedService {
   my ($self, $srvName) = @_;
@@ -824,7 +824,7 @@ sub parseSchedule {
     $self->warn("can't parse schedule " . $string);
   }
 
-} ## end sub parseSchedule
+}
 
 sub isRoute {
   my ($self, $string) = @_;
@@ -869,7 +869,7 @@ sub parseRoute {
     $self->warn("can't parse route " . $string);
   }
 
-} ## end sub parseRoute
+}
 
 sub isDynamicNat {
   my ($self, $string) = @_;
@@ -1005,8 +1005,8 @@ sub parseDynamicNat {
     my $dyNat = Firewall::Config::Element::DynamicNat::H3c->new(%param);
     $self->addElement($dyNat);
 
-  } ## end elsif ( $string =~ /nat\s+server\s+(protocol\s+(?<proto>\S+)\s+)?global\s+ )
-} ## end sub parseDynamicNat
+  }
+}
 
 sub addRouteToInterface {
   my $self       = shift;
@@ -1034,10 +1034,10 @@ sub addRouteToInterface {
         }
 
       }
-    } ## end if ( $route->type eq 'static')
-  } ## end for my $route ( values ...)
+    }
+  }
 
-} ## end sub addRouteToInterface
+}
 
 sub addZoneRange {
   my $self = shift;
@@ -1151,12 +1151,12 @@ sub parseRule {
           $self->addToRuleServiceGroup($rule, 'any') if $isNew;
         }
 
-      } ## end if ( $string =~ /rule\s+(?<id>\d+)\s+(?<action>\S+) )
+      }
 
-    } ## end while ( defined( my $string...))
+    }
 
-  } ## end if ( $string =~ /object-policy\s+ip\s+(?<name>\S+)/)
-} ## end sub parseRule
+  }
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName, $type) = @_;
@@ -1189,7 +1189,7 @@ sub addToRuleSrcAddressGroup {
   }
 
   $rule->addSrcAddressMembers($name, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName, $type) = @_;
@@ -1222,7 +1222,7 @@ sub addToRuleDstAddressGroup {
     $obj->addMember({range => "$dstAddrName"});
   }
   $rule->addDstAddressMembers($name, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
@@ -1240,7 +1240,7 @@ sub addToRuleServiceGroup {
       $self->warn("的 srvName $srvName 不是 service 不是 preDefinedService 也不是 serviceGroup\n");
     }
   }
-} ## end sub addToRuleServiceGroup
+}
 
 sub getInterfaceFromRoute {
   my ($self, $srcSet, $dstSet) = @_;
@@ -1257,7 +1257,7 @@ sub getInterfaceFromRoute {
   }
   return;
 
-} ## end sub getInterfaceFromRoute
+}
 
 sub getPortName {
   my ($self, $portName) = @_;
@@ -1294,7 +1294,7 @@ sub getPortName {
   $portHash{whois}      = 43;
   $portHash{www}        = 80;
   return $portHash{$portName};
-} ## end sub getPortName
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
