@@ -51,9 +51,9 @@ sub parse {
     elsif ($self->isSchedule($string))     { $self->parseSchedule($string) }
     elsif ($self->isRule($string))         { $self->parseRule($string) }
     else                                   { $self->ignoreLine }
-  } ## end while ( defined( my $string...))
+  }
   $self->{config} = "";
-} ## end sub parse
+}
 
 sub isActive {
   my ($self, $string) = @_;
@@ -90,9 +90,9 @@ sub setActive {
       confess "$@";
     }
 
-  } ## end if ( $string =~ /.+\((.+)\)->\s*/i)
+  }
 
-} ## end sub setActive
+}
 
 #set interface ethernet1/3.2 vip 210.21.223.59 25000 "5000" 192.168.170.228
 #set interface ethernet1/3.2 vip 210.21.223.59 + 15000 "5000" 192.168.170.227
@@ -146,7 +146,7 @@ sub parseDynamicNat {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseDynamicNat
+}
 
 sub isNatPool {
   my ($self, $string) = @_;
@@ -185,7 +185,7 @@ sub parseNatPool {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseNatPool
+}
 
 #set interface "ethernet0/0" zone "INS_DR"
 #set interface ethernet0/0 ip 172.20.255.81/29
@@ -222,7 +222,7 @@ sub addRouteToInterface {
       }
     }
   }
-} ## end sub addRouteToInterface
+}
 
 sub addZoneRange {
   my $self = shift;
@@ -268,7 +268,7 @@ sub getZoneFromIp {
     }
 =cut
 
-} ## end sub getZoneFromIp
+}
 
 sub parseInterfaceZone {
   my ($self, $string) = @_;
@@ -360,7 +360,7 @@ set interface ethernet0/0 ip 172.20.255.81/29
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseInterfaceZone
+}
 
 #set route 10.0.0.0/8 interface ethernet0/0 gateway 10.37.172.200 preference 20
 #set route source 10.88.138.41/32 interface ethernet0/2.1 gateway 113.140.11.129
@@ -452,7 +452,7 @@ set route 172.20.24.0/22 gateway 172.20.255.86
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseRoute
+}
 
 sub isStaticNat {
   my ($self, $string) = @_;
@@ -534,7 +534,7 @@ set interface "ethernet0/0" mip 10.37.172.25 host 192.168.184.25 netmask 255.255
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseStaticNat
+}
 
 sub isAddress {
   my ($self, $string) = @_;
@@ -589,7 +589,7 @@ set address "V1-Untrust" "Host_10.29.38.10" 10.29.38.10 255.255.255.255 "hsh-121
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseAddress
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -666,7 +666,7 @@ set group address "V1-Trust" "A_LINUX_DNS_2012" add "H_10.31.120.2"
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseAddressGroup
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $zone, $addrGroupMemberName) = @_;
@@ -799,7 +799,7 @@ set service "my-sunrpc-nfs" + sun-rpc program 100227-100227
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseService
+}
 
 sub isServiceGroup {
   my ($self, $string) = @_;
@@ -878,7 +878,7 @@ set group service "BKUP_SERVICES" add "TCP/UDP_27238"
   else {
     $self->warn("$string 但分析不出来\n");
   }
-} ## end sub parseServiceGroup
+}
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
   my ($self, $srvGroupMemberName) = @_;
@@ -983,7 +983,7 @@ set scheduler "S20110630" recurrent friday start 10:00 stop 12:00 start 14:00 st
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseSchedule
+}
 
 sub getDynamicNat {
   my ($self, $policyId) = @_;
@@ -1149,7 +1149,7 @@ exit
           }
           my $dynamicNat = Firewall::Config::Element::DynamicNat::Netscreen->new(%natParam);
           $self->addElement($dynamicNat);
-        } ## end if ( defined $+{poolName...})
+        }
 
         $self->addElement($rule);
         my $index = $fromZone . $toZone;
@@ -1217,9 +1217,9 @@ exit
       else {
         $self->warn("id 为 $policyId 的行 [$string] 分析不出来\n");
       }
-    } ## end else [ if ( $string =~ /^set \s+ policy \s+ id )]
+    }
   } while ($string = $self->nextUnParsedLine);
-} ## end sub parseRule
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName) = @_;
@@ -1245,7 +1245,7 @@ sub addToRuleSrcAddressGroup {
   }
 
   $rule->addSrcAddressMembers($srcAddrName, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName) = @_;
@@ -1271,7 +1271,7 @@ sub addToRuleDstAddressGroup {
   }
 
   $rule->addDstAddressMembers($dstAddrName, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
