@@ -9,22 +9,13 @@ use namespace::autoclean;
 #------------------------------------------------------------------------------
 # Firewall::Config::Parser::Report 通用属性
 #------------------------------------------------------------------------------
-has source =>
-  ( is => 'ro', isa => 'HashRef[Firewall::Policy::Element::Source]', default => sub { {} }, writer => 'setSource', );
+has source => (is => 'ro', isa => 'HashRef[Firewall::Policy::Element::Source]', default => sub { {} }, writer => 'setSource',);
 
-has destination => (
-  is      => 'ro',
-  isa     => 'HashRef[Firewall::Policy::Element::Destination]',
-  default => sub { {} },
-  writer  => 'setDestination',
-);
+has destination =>
+  (is => 'ro', isa => 'HashRef[Firewall::Policy::Element::Destination]', default => sub { {} }, writer => 'setDestination',);
 
-has service => (
-  is      => 'ro',
-  isa     => 'HashRef[HashRef[Firewall::Policy::Element::Service]]',
-  default => sub { {} },
-  writer  => 'setService',
-);
+has service =>
+  (is => 'ro', isa => 'HashRef[HashRef[Firewall::Policy::Element::Service]]', default => sub { {} }, writer => 'setService',);
 
 __PACKAGE__->meta->make_immutable;
 1;
