@@ -55,14 +55,14 @@ sub parse {
     elsif ($self->isServiceGroup($string)) { $self->parseServiceGroup($string) }
     elsif ($self->isSchedule($string))     { $self->parseSchedule($string) }
     else                                   { $self->ignoreLine }
-  } ## end while ( my $string = $self...)
+  }
 
   $self->goToHeadLine;
   while (my $string = $self->nextUnParsedLine) {
     if   ($self->isRule($string)) { $self->parseRule($string) }
     else                          { $self->ignoreLine }
   }
-} ## end sub parse
+}
 
 sub isActive {
   my ($self, $string) = @_;
@@ -94,8 +94,8 @@ sub setActive {
     if (!!$@) {
       $self->warn($@);
     }
-  } ## end if ( $string =~ /{(\S+):node.+}\s*/i)
-} ## end sub setActive
+  }
+}
 
 # set security nat source rule-set
 sub isDynamicNat {
@@ -275,17 +275,17 @@ sub parseDynamicNat {
               $dynamicNat->srcIpRange->mergeToSet(0, 4294967295);
             }
 
-          } ## end elsif ( $+{natDirection} ...)
+          }
 
         }
         else {
           $self->warn("DynamicNat 定义错误!");
         }
-      } ## end elsif ( $string =~ /^set \s+ security \s+ nat \s+ (?<natDirection>\S+) \s+ rule-set )
-    } ## end else [ if ( $string =~ /^set \s+ security \s+ nat \s+ (?<natDirection>\S+) \s+ rule-set )]
-  } ## end while ( $string = $self->...)
+      }
+    }
+  }
 
-} ## end sub parseDynamicNat
+}
 
 sub isNatPool {
   my ($self, $string) = @_;
@@ -338,7 +338,7 @@ sub parseNatPool {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseNatPool
+}
 
 sub getZoneFromRoute {
   my ($self, $ipSet) = @_;
@@ -412,7 +412,7 @@ sub parseZone {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseZone
+}
 
 sub isInterface {
   my ($self, $string) = @_;
@@ -519,7 +519,7 @@ sub parseInterface {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseInterface
+}
 
 sub addRouteToInterface {
   my $self           = shift;
@@ -563,9 +563,9 @@ sub addRouteToInterface {
       }
 
     }
-  } ## end for my $route ( values ...)
+  }
 
-} ## end sub addRouteToInterface
+}
 
 sub addZoneRange {
   my $self = shift;
@@ -660,7 +660,7 @@ sub parseRoute {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseRoute
+}
 
 sub isStaticNat {
   my ($self, $string) = @_;
@@ -792,10 +792,10 @@ sub parseStaticNat {
       {
 
       }
-    } ## end else [ if ( $string =~ /^set \s+ security \s+ nat \s+ static \s+ rule-set )]
-  } ## end while ( $string = $self->...)
+    }
+  }
 
-} ## end sub parseStaticNat
+}
 
 sub getZoneFromIp {
   my ($self, $network) = @_;
@@ -897,7 +897,7 @@ sub parseAddress {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseAddress
+}
 
 sub isAddressGroup {
   my ($self, $string) = @_;
@@ -986,7 +986,7 @@ sub parseAddressGroup {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseAddressGroup
+}
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
   my ($self, $zone, $addrGroupMemberName) = @_;
@@ -1080,7 +1080,7 @@ sub parseService {
           $self->addElement($service);
         }
         %params = ();
-      } ## end if ( keys %params > 0 ...)
+      }
 
       if (keys %params == 0) {
         %params = (fwId => $self->fwId, srvName => $srvName, term => $term, config => $string);
@@ -1115,7 +1115,7 @@ sub parseService {
     else {
       $self->warn("$string 分析不出来\n");
     }
-  } ## end while ( $string = $self->...)
+  }
 
   #new or addMeta
 
@@ -1129,7 +1129,7 @@ sub parseService {
     $self->addElement($service);
   }
 
-} ## end sub parseService
+}
 
 sub isServiceGroup {
   my ($self, $string) = @_;
@@ -1194,7 +1194,7 @@ sub parseServiceGroup {
   else {
     $self->warn("$string 但分析不出来\n");
   }
-} ## end sub parseServiceGroup
+}
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
   my ($self, $srvGroupMemberName) = @_;
@@ -1256,7 +1256,7 @@ sub parseSchedule {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseSchedule
+}
 
 sub isRule {
   my ($self, $string) = @_;
@@ -1403,7 +1403,7 @@ sub parseRule {
   else {
     $self->warn("$string 分析不出来\n");
   }
-} ## end sub parseRule
+}
 
 sub addToRuleSrcAddressGroup {
   my ($self, $rule, $srcAddrName) = @_;
@@ -1429,7 +1429,7 @@ sub addToRuleSrcAddressGroup {
   }
 
   $rule->addSrcAddressMembers($srcAddrName, $obj);
-} ## end sub addToRuleSrcAddressGroup
+}
 
 sub addToRuleDstAddressGroup {
   my ($self, $rule, $dstAddrName) = @_;
@@ -1455,7 +1455,7 @@ sub addToRuleDstAddressGroup {
   }
 
   $rule->addDstAddressMembers($dstAddrName, $obj);
-} ## end sub addToRuleDstAddressGroup
+}
 
 sub addToRuleServiceGroup {
   my ($self, $rule, $srvName) = @_;
